function Y0_0 = int_compute_Y0(x,tu,par,A,nu)

omega = par(1); % Frequency of the periodic orbit
n = mid(par(2)); % Number of bodies in the choreography
k = mid(par(3)); % Defines the symmetry of the choreography
zeta = 2*intval('pi')/n;
s1 = sum(1./sin((1:n-1)*zeta/2))/4;

x = intval(x);
omega = intval(omega);
nu = intval(nu);

% lambda in C^3: unfolding parameters for the three conserved quantities
lambda = x(1:3);

%alpha in C^{n-1}: unfolding parameters for the n-1 extra init. conditions
alpha = x(4:n+2);

m = (length(x)+3)/(2*(n+5)); % The Fourier projection per component

%u : Fourier coefficients of u(t) = (x(t),y(t),z(t))
u = reshape(x(n+3:6*m+n-1),2*m-1,3); %u_1 = u(:,1); u_2 = u(:,2); u_3 = u(:,3);
u1 = u(:,1); u2 = u(:,2); u3 = u(:,3);

%v : Fourier coefficients of v(t) = u'(t) = (x'(t),y'(t),z'(t))
v = reshape(x(6*m+n:12*m+n-4),2*m-1,3);
v1 = v(:,1); v2 = v(:,2); v3 = v(:,3);

%w : Fourier coefficients of w(t) = (w_1(t),...,w_{n-1}(t))
w = reshape(x(12*m+n-3:2*m*(n+5)-3),2*m-1,n-1); %w_1 = w(:,1); ... w_{n-1} = w(:,n-1);

i1 = (1:2*m-1)'; i2 = i1+2*m-1; i3 = i2+2*m-1;

%%%% Define the indices corresponding to the variables

i_lambda = (1:3);
i_alpha = i_lambda(end) + (1:n-1);
i_u1 = i_alpha(end) + (1:2*m-1);
i_u2 = i_u1(end) + (1:2*m-1);
i_u3 = i_u2(end) + (1:2*m-1);
i_v1 = i_u3(end) + (1:2*m-1);
i_v2 = i_v1(end) + (1:2*m-1);
i_v3 = i_v2(end) + (1:2*m-1);

i_wj = zeros(n-1,2*m-1);
i_wj(1,:) = i_v3(end) + (1:2*m-1);

for j=1:n-1
    i_wj(j+1,:) = i_wj(j,end) + (1:2*m-1);
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% eta - Conserved quantities %%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

tu = intval(tu);

tu1 = tu(i1); tu2 = tu(i2); tu3 = tu(i3);

ell = (-m+1:m-1)';

I1 = -transpose(u1)*flip(tu2)+transpose(u2)*flip(tu1);
tu1p = 1i*ell.*tu1; tu2p = 1i*ell.*tu2; tu3p = 1i*ell.*tu3;
I2 = transpose(u1)*flip(tu1p)+transpose(u2)*flip(tu2p)+transpose(u3)*flip(tu3p);
I3 = u3(m);

eta = [I1;I2;I3];

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% gamma - extra initial conition %%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

gamma = intval(zeros(n-1,1));

for j=1:n-1
    
    Mju = M_j([u1;u2;u3],j,k,zeta);
    
    Mju1 = Mju(i1); Mju2 = Mju(i2); Mju3 = Mju(i3);
    
    wj = w(:,j);
    
    sum1 = real(sum(Mju1)); % for real symmetric data, we know theoretically that imag part = 0 
    sum2 = real(sum(Mju2)); % for real symmetric data, we know theoretically that imag part = 0 
    sum3 = real(sum(Mju3)); % for real symmetric data, we know theoretically that imag part = 0 
   
    gamma(j) = sum(wj)^2*(sum1^2+sum2^2+sum3^2)-1;
    
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% f = f(u,v) = Du - v %%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%

f = [1i*ell.*u1-v1;1i*ell.*u2-v2;1i*ell.*u3-v3];

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% g = g(u,v,w,omega) = omega^2*Dv + ... %%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

one = zeros(2*m-1,1); one(m) = 1;

g1_linear = omega^2*1i*ell.*v1 - 2*omega*sqrt(s1)*v2 - s1*u1 - lambda(1)*u2 + lambda(2)*v1;
g2_linear = omega^2*1i*ell.*v2 + 2*omega*sqrt(s1)*v1 - s1*u2 + lambda(1)*u1 + lambda(2)*v2;
g3_linear = omega^2*1i*ell.*v3                                              + lambda(2)*v3 + lambda(3)*one ;

g1_nonlinear = zeros(8*m-1,1); g2_nonlinear = zeros(8*m-1,1); g3_nonlinear = zeros(8*m-1,1);

for j = 1:n-1
    
    wj = w(:,j);
    
    Mju = M_j([u1;u2;u3],j,k,zeta);
    
    Mju1 = Mju(i1); Mju2 = Mju(i2); Mju3 = Mju(i3);
    
    Mju1wj3 = [zeros(3,1);rig_conv_2sided([Mju1 wj wj wj]);zeros(3,1)];
    Mju2wj3 = [zeros(3,1);rig_conv_2sided([Mju2 wj wj wj]);zeros(3,1)];
    Mju3wj3 = [zeros(3,1);rig_conv_2sided([Mju3 wj wj wj]);zeros(3,1)];
    
    g1_nonlinear = g1_nonlinear + Mju1wj3;
    g2_nonlinear = g2_nonlinear + Mju2wj3;
    g3_nonlinear = g3_nonlinear + Mju3wj3;
    
end

index = -(m-1):(m-1);

g_m = [g1_linear + g1_nonlinear(4*m+index);
       g2_linear + g2_nonlinear(4*m+index);
       g3_linear + g3_nonlinear(4*m+index)];

ell1 = (-4*m+1:-m)'; ell2 = (m:4*m-1)';

delta_g1 = sum(abs((g1_nonlinear(1:3*m)./(1i*ell1*omega^2)).*nu.^abs(ell1))) + sum(abs((g1_nonlinear(5*m:8*m-1)./(1i*ell2*omega^2)).*nu.^abs(ell2))) ;
delta_g2 = sum(abs((g2_nonlinear(1:3*m)./(1i*ell1*omega^2)).*nu.^abs(ell1))) + sum(abs((g2_nonlinear(5*m:8*m-1)./(1i*ell2*omega^2)).*nu.^abs(ell2))) ;
delta_g3 = sum(abs((g3_nonlinear(1:3*m)./(1i*ell1*omega^2)).*nu.^abs(ell1))) + sum(abs((g3_nonlinear(5*m:8*m-1)./(1i*ell2*omega^2)).*nu.^abs(ell2))) ;

%%%%%%%%%%%%%%%%%%%%
%%% h = h(u,v,w) %%%
%%%%%%%%%%%%%%%%%%%%

h_m = intval(zeros((2*m-1)*(n-1),1));

index_m = (1:2*m-1)';
index_tail = (1:10*m-1)';

for j = 1 : n-1
    
    wj = w(:,j);
    
    Mju = M_j([u1;u2;u3],j,k,zeta);
    Mjv = M_j([v1;v2;v3],j,k,zeta);

    wj3_Mju1_Mjv1 = [zeros(4,1);rig_conv_2sided([wj wj wj Mju(i1) Mjv(i1)]);zeros(4,1)];
    wj3_Mju2_Mjv2 = [zeros(4,1);rig_conv_2sided([wj wj wj Mju(i2) Mjv(i2)]);zeros(4,1)];
    wj3_Mju3_Mjv3 = [zeros(4,1);rig_conv_2sided([wj wj wj Mju(i3) Mjv(i3)]);zeros(4,1)];
    
    wj3 = [zeros(2,1);rig_conv_2sided([wj wj wj]);zeros(2,1)];
    
    h_m(index_m) = 1i*ell.*wj + wj3_Mju1_Mjv1(5*m+index) + wj3_Mju2_Mjv2(5*m+index) + wj3_Mju3_Mjv3(5*m+index) + alpha(j)*wj3(3*m+index);
    
    ell1 = (-5*m+1:-m)'; ell2 = (m:5*m-1)'; ell1_3 = (-3*m+1:-m)'; ell2_3 = (m:3*m-1)';
    
    delta_hi = sum(abs((wj3_Mju1_Mjv1(1:4*m)./(1i*ell1)).*nu.^abs(ell1))) + sum(abs((wj3_Mju1_Mjv1(6*m:10*m-1)./(1i*ell2)).*nu.^abs(ell2))) ...
             + sum(abs((wj3_Mju2_Mjv2(1:4*m)./(1i*ell1)).*nu.^abs(ell1))) + sum(abs((wj3_Mju2_Mjv2(6*m:10*m-1)./(1i*ell2)).*nu.^abs(ell2))) ...
             + sum(abs((wj3_Mju3_Mjv3(1:4*m)./(1i*ell1)).*nu.^abs(ell1))) + sum(abs((wj3_Mju3_Mjv3(6*m:10*m-1)./(1i*ell2)).*nu.^abs(ell2))) ...
             + abs(alpha(j))*(sum(abs((wj3(1:2*m)./(1i*ell1_3)).*nu.^abs(ell1_3))) + sum(abs((wj3(4*m:6*m-1)./(1i*ell2_3)).*nu.^abs(ell2_3))));
    
    index_m = index_m + 2*m-1;
    index_tail = index_tail + 10*m-1;
    
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% F = [eta;gamma;f;g;h] %%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

F0 = [eta;gamma;f;g_m;h_m];
y0 = intval(A)*F0;

norm_y0_lambda = norm(y0(i_lambda),inf);
norm_y0_alpha = norm(y0(i_alpha),inf);
norm_y0_u = max([norm_nu(y0(i_u1),nu) norm_nu(y0(i_u2),nu) norm_nu(y0(i_u3),nu)]);
norm_y0_v = max([norm_nu(y0(i_v1),nu)+delta_g1 norm_nu(y0(i_v2),nu)+delta_g2 norm_nu(y0(i_v3),nu)+delta_g3]);

norm_y0_w = 0;

for j=1:n-1
    norm_y0_w = max([sup(norm_nu(y0(i_wj(j,:)),nu)+delta_hi) norm_y0_w]);
end

Y0_0 = max([norm_y0_lambda norm_y0_alpha norm_y0_u norm_y0_v norm_y0_w]);

end
