function [Z1] = int_compute_Z1(x,par,A,nu)

omega0 = intval(par(1)); % Frequency of the periodic orbit
n = mid(par(2));
k = mid(par(3));
zeta = 2*intval('pi')/n;
s1 = sum(1./sin((1:n-1)*zeta/2))/4;

x = intval(x);
nu = intval(nu);

m = (length(x)+3)/(2*(n+5)); % The Fourier projection per component

%u : Fourier coefficients of u(t) = (x(t),y(t),z(t))
u = reshape(x(n+3:6*m+n-1),2*m-1,3); %u_1 = u(:,1); u_2 = u(:,2); u_3 = u(:,3);
u1 = u(:,1); u2 = u(:,2); u3 = u(:,3);

%v : Fourier coefficients of v(t) = u'(t) = (x'(t),y'(t),z'(t))
v = reshape(x(6*m+n:12*m+n-4),2*m-1,3);
v1 = v(:,1); v2 = v(:,2); v3 = v(:,3);

%w : Fourier coefficients of w(t) = (w_1(t),...,w_{n-1}(t))
w = reshape(x(12*m+n-3:2*m*(n+5)-3),2*m-1,n-1); %w_1 = w(:,1); ... w_{n-1} = w(:,n-1);

i1 = (1:2*m-1)'; i2 = i1+2*m-1; i3 = i2+2*m-1;

%%%% Define the indices corresponding to the variables

i_lambda = (1:3);
i_alpha = i_lambda(end) + (1:n-1);
i_u1 = i_alpha(end) + (1:2*m-1);
i_u2 = i_u1(end) + (1:2*m-1);
i_u3 = i_u2(end) + (1:2*m-1);
i_v1 = i_u3(end) + (1:2*m-1);
i_v2 = i_v1(end) + (1:2*m-1);
i_v3 = i_v2(end) + (1:2*m-1);

i_wj = zeros(n-1,2*m-1);
i_wj(1,:) = i_v3(end) + (1:2*m-1);

for j=1:n-1
    i_wj(j+1,:) = i_wj(j,end) + (1:2*m-1);
end

z = intval(zeros(length(x),1));

%%%%%%%%%%%
% z_gamma %
%%%%%%%%%%%

z_gamma = intval(zeros(n-1,1));

for j=1:n-1
    
    Mju = M_j([u1;u2;u3],j,k,zeta);
    
    Mju1 = Mju(i1); Mju2 = Mju(i2); Mju3 = Mju(i3);
    
    wj = w(:,j);
    
    sum1 = real(sum(Mju1)); % for real symmetric data, we know theoretically that imag part = 0 
    sum2 = real(sum(Mju2)); % for real symmetric data, we know theoretically that imag part = 0 
    sum3 = real(sum(Mju3)); % for real symmetric data, we know theoretically that imag part = 0 
    
    z_gamma(j) = (2/nu^m)*( abs(sum(wj))*(abs(sum1^2)+abs(sum2^2)+abs(sum3^2)) + abs(sum(wj)^2)*( 3*abs(sum1) + 3*abs(sum2) + 2*abs(sum3) ) ) ;
    
end

z(i_alpha) = z_gamma;

%%%%%%%
% z_v %
%%%%%%%

zv1 = intval(zeros(2*m-1,1)); zv2 = intval(zeros(2*m-1,1)); zv3 = intval(zeros(2*m-1,1));

for j=1:n-1
    
    Mju = M_j([u1;u2;u3],j,k,zeta);
    wj = w(:,j);
    wj3 = rig_conv_2sided([wj wj wj]);
    Mju1wj2 = rig_conv_2sided([Mju(i1) wj wj]);
    Mju2wj2 = rig_conv_2sided([Mju(i2) wj wj]);
    Mju3wj2 = rig_conv_2sided([Mju(i3) wj wj]);
    
    zv1 = zv1 + 3*int_Psi_bound(wj3,m,nu) + 3*int_Psi_bound(Mju1wj2,m,nu); % p = 1
    zv2 = zv2 + 3*int_Psi_bound(wj3,m,nu) + 3*int_Psi_bound(Mju2wj2,m,nu); % p = 2
    zv3 = zv3 + 2*int_Psi_bound(wj3,m,nu) + 3*int_Psi_bound(Mju3wj2,m,nu); % p = 3
    
end

z(i_v1) = zv1; z(i_v2) = zv2; z(i_v3) = zv3;

%%%%%%%
% z_w %
%%%%%%%

alpha = x(i_alpha);

for j=1:n-1
    
    Mju = M_j([u1;u2;u3],j,k,zeta);
    Mjv = M_j([v1;v2;v3],j,k,zeta);
    wj = w(:,j);
    
    wj2 = [0;rig_conv_2sided([wj wj]);0];
    
    wj2Mju1Mjv1 = rig_conv_2sided([wj wj Mju(i1) Mjv(i1)]);
    wj2Mju2Mjv2 = rig_conv_2sided([wj wj Mju(i2) Mjv(i2)]);
    wj2Mju3Mjv3 = rig_conv_2sided([wj wj Mju(i3) Mjv(i3)]);
    
    wj3Mjv1 = rig_conv_2sided([wj wj wj Mjv(i1)]);
    wj3Mjv2 = rig_conv_2sided([wj wj wj Mjv(i2)]);
    wj3Mjv3 = rig_conv_2sided([wj wj wj Mjv(i3)]);
    
    wj3Mju1 = rig_conv_2sided([wj wj wj Mju(i1)]);
    wj3Mju2 = rig_conv_2sided([wj wj wj Mju(i2)]);
    wj3Mju3 = rig_conv_2sided([wj wj,wj Mju(i3)]);
           
    term1 = 3*int_Psi_bound(wj2Mju1Mjv1,m,nu) + 3*int_Psi_bound(wj3Mjv1,m,nu) + 3*int_Psi_bound(wj3Mju1,m,nu);
    term2 = 3*int_Psi_bound(wj2Mju2Mjv2,m,nu) + 3*int_Psi_bound(wj3Mjv2,m,nu) + 3*int_Psi_bound(wj3Mju2,m,nu);
    term3 = 3*int_Psi_bound(wj2Mju3Mjv3,m,nu) + 3*int_Psi_bound(wj3Mjv3,m,nu) + 2*int_Psi_bound(wj3Mju3,m,nu);
    
    z(i_wj(j,:)) = 3*abs(alpha(j))*int_Psi_bound(wj2,m,nu) + term1 + term2 + term3 ;
    
end

hat_zm = abs(A)*z;

lambda = x(i_lambda);

norm_hat_zm_lbda = norm(hat_zm(i_lambda),inf);
norm_hat_zm_alpha = norm(hat_zm(i_alpha),inf);
norm_hat_z_u = max([norm_nu(hat_zm(i_u1),nu)+1/m norm_nu(hat_zm(i_u2),nu)+1/m norm_nu(hat_zm(i_u3),nu)+1/m]);

delta_v_1 = (1/(m*omega0^2))*(2*omega0*sqrt(s1)+s1+norm_nu(u2,nu)+abs(lambda(1))+abs(lambda(2))+norm_nu(v1,nu));
delta_v_2 = (1/(m*omega0^2))*(2*omega0*sqrt(s1)+s1+norm_nu(u1,nu)+abs(lambda(1))+abs(lambda(2))+norm_nu(v2,nu));
delta_v_3 = (1/(m*omega0^2))*(abs(lambda(2))+norm_nu(v3,nu));

for j=1:n-1
    Mju = M_j([u1;u2;u3],j,k,zeta);
    wj = w(:,j);
    delta_v_1 = delta_v_1 + (1/(m*omega0^2))*(3*norm_nu(wj,nu)^3+3*norm_nu(Mju(i1),nu)*norm_nu(wj,nu)^2);
    delta_v_2 = delta_v_2 + (1/(m*omega0^2))*(3*norm_nu(wj,nu)^3+3*norm_nu(Mju(i2),nu)*norm_nu(wj,nu)^2);
    delta_v_3 = delta_v_3 + (1/(m*omega0^2))*(2*norm_nu(wj,nu)^3+3*norm_nu(Mju(i3),nu)*norm_nu(wj,nu)^2);
end

norm_hat_z_v = max([norm_nu(hat_zm(i_v1),nu)+delta_v_1 norm_nu(hat_zm(i_v2),nu)+delta_v_2 norm_nu(hat_zm(i_v3),nu)+delta_v_3]);

norm_hat_z_wj = 0;

for j=1:n-1
    wj = w(:,j);
    Mju = M_j([u1;u2;u3],j,k,zeta);
    Mjv = M_j([v1;v2;v3],j,k,zeta);
    sum0 = norm_nu(wj,nu)^3 + 3*abs(alpha(j))*norm_nu(wj,nu)^2 ;
    sum1 = 3*norm_nu(wj,nu)^2*norm_nu(Mju(i1),nu)*norm_nu(Mjv(i1),nu) + 3*norm_nu(wj,nu)^3*(norm_nu(Mju(i1),nu)+norm_nu(Mjv(i1),nu));
    sum2 = 3*norm_nu(wj,nu)^2*norm_nu(Mju(i2),nu)*norm_nu(Mjv(i2),nu) + 3*norm_nu(wj,nu)^3*(norm_nu(Mju(i2),nu)+norm_nu(Mjv(i2),nu)); 
    sum3 = 3*norm_nu(wj,nu)^2*norm_nu(Mju(i3),nu)*norm_nu(Mjv(i3),nu) + 2*norm_nu(wj,nu)^3*(norm_nu(Mju(i3),nu)+norm_nu(Mjv(i3),nu));
    delta_wj = (sum0+sum1+sum2+sum3)/m ; 
    norm_hat_z_wj = max([norm_hat_z_wj norm_nu(hat_zm(i_wj(j,:)),nu)+delta_wj]);
end

Z1 = max([norm_hat_zm_lbda norm_hat_zm_alpha norm_hat_z_u norm_hat_z_v norm_hat_z_wj]);

end
