function [x,tu] = padding_choreography(x,tu,par,m1)

n = par(2); % Number of bodies in the choreography

% lambda in C^3: unfolding parameters for the three conserved quantities
lambda = x(1:3); 

%alpha in C^{n-1}: unfolding parameters for the n-1 extra init. conditions
alpha = x(4:n+2);

m = (length(x)+3)/(2*(n+5)); % The Fourier projection per component

%u : Fourier coefficients of u(t) = (x(t),y(t),z(t))
u = reshape(x(n+3:6*m+n-1),2*m-1,3); %u_1 = u(:,1); u_2 = u(:,2); u_3 = u(:,3);
u1 = [zeros(m1,1);u(:,1);zeros(m1,1)]; 
u2 = [zeros(m1,1);u(:,2);zeros(m1,1)]; 
u3 = [zeros(m1,1);u(:,3);zeros(m1,1)];

%v : Fourier coefficients of v(t) = u'(t) = (x'(t),y'(t),z'(t))
v = reshape(x(6*m+n:12*m+n-4),2*m-1,3); 
v1 = [zeros(m1,1);v(:,1);zeros(m1,1)]; 
v2 = [zeros(m1,1);v(:,2);zeros(m1,1)]; 
v3 = [zeros(m1,1);v(:,3);zeros(m1,1)];

%w : Fourier coefficients of w(t) = (w_1(t),...,w_{n-1}(t))
w = [zeros(m1,n-1);reshape(x(12*m+n-3:2*m*(n+5)-3),2*m-1,n-1);zeros(m1,n-1)]; %w_1 = w(:,1); ... w_{n-1} = w(:,n-1);

x = [lambda;alpha;u1;u2;u3;v1;v2;v3];

for j = 1:n-1
    x = [x;w(:,j)];
end

i1 = (1:2*m-1)'; i2 = i1+2*m-1; i3 = i2+2*m-1;

tu1 = [zeros(m1,1);tu(i1);zeros(m1,1)];
tu2 = [zeros(m1,1);tu(i2);zeros(m1,1)];
tu3 = [zeros(m1,1);tu(i3);zeros(m1,1)];
tu = [tu1;tu2;tu3];

end

